@@ -18,73 +18,66 @@ try:
     from six import string_types, binary_type
 except ImportError:  # pragma: no cover
     import warnings
-    warnings.warn("Ignoring six. Probably setup.py installing package.")
+    warnings.warn('Ignoring six. Probably setup.py installing package.')
 
 import numbers
 
 from preggy import assertion
 
-DATE_THRESHOLD = 5.0
-RESET = "\033[m"
-RED = "\033[31m"
-GREEN = "\033[32m"
-YELLOW = "\033[33m"
-
+__all__ = ('to_be_like', 'not_to_be_like')
 
 #-------------------------------------------------------------------------------------------------
 # Helpers
 #-------------------------------------------------------------------------------------------------
+DATE_THRESHOLD = 5.0
+
+RESET = '\033[m'
+RED = '\033[31m'
+GREEN = '\033[32m'
+YELLOW = '\033[33m'
+
 REMOVE_COLORS_REGEX = re.compile(
     r'(\033|\x1b|\x03)'  # prefixes
     r'\['                # non-regex bracket
     r'([0-9]*[;])?'      # semi-colon
     r'[0-9]*m',          # suffix
-    re.UNICODE
+    flags=re.UNICODE
 )
-_filter_str = lambda s: s.strip().lower().replace(' ', '').replace('\n', '').replace('\t', '').replace('\r', '')
 
+NORMALIZE_WHITESPACE_REGEX = re.compile(
+    r'\s+',
+    flags=re.UNICODE|re.MULTILINE|re.IGNORECASE
+)
+
+_filter_str = lambda s: NORMALIZE_WHITESPACE_REGEX.sub('', s.lower()).strip()
 
 def compare(first, second):
     matcher = difflib.SequenceMatcher(None, first, second)
     first = get_match_for_text(matcher, first, True)
     second = get_match_for_text(matcher, second, True)
-
     return matcher, first, second
 
 
 def get_match_for_text(matcher, text, first):
     result = []
+    COLOR_MAP = {
+        'delete': RED,
+        'insert': GREEN,
+        'replace': YELLOW
+    }
+
     for tag, i1, i2, j1, j2 in matcher.get_opcodes():
+        start, stop = (i1, i2) if first else (j1, j2)
+        to_append = text[start:stop]
+        if tag in COLOR_MAP:
+            to_append = ''.join((COLOR_MAP[tag], to_append, RESET))
+        result.append(to_append)
 
-        if tag == 'delete':
-            if first:
-                result.append("%s%s%s" % (RED, text[i1:i2], RESET))
-            else:
-                result.append("%s%s%s" % (RED, text[j1:j2], RESET))
-
-        elif tag == 'equal':
-            if first:
-                result.append(text[i1:i2])
-            else:
-                result.append(text[j1:j2])
-
-        elif tag == 'insert':
-            if first:
-                result.append("%s%s%s" % (GREEN, text[i1:i2], RESET))
-            else:
-                result.append("%s%s%s" % (GREEN, text[j1:j2], RESET))
-
-        elif tag == 'replace':
-            if first:
-                result.append("%s%s%s" % (YELLOW, text[i1:i2], RESET))
-            else:
-                result.append("%s%s%s" % (YELLOW, text[j1:j2], RESET))
-
-    return "".join(result)
+    return ''.join(result)
 
 
 def _match_alike(expected, topic):
-    '''Asserts the "like"-ness of `topic` and `expected` according to their types.'''
+    '''Determines the types of `expected` and `topic`, and calls the appropriate comparison function.'''
     if topic is None:
         return expected is None
     if isinstance(topic, string_types + (binary_type, )):
@@ -103,13 +96,10 @@ def _match_alike(expected, topic):
 def _strip_string(text):
     if isinstance(text, (binary_type, )):
         text = text.decode('utf-8')
-
     text = REMOVE_COLORS_REGEX.sub('', text)
     text = _filter_str(text)
-
     if isinstance(text, (binary_type, )):
         text = text.decode('utf-8')
-
     return text
 
 
@@ -120,20 +110,19 @@ def _compare_strings(expected, topic):
     '''
     topic = _strip_string(topic)
     expected = _strip_string(expected)
-
     return expected == _filter_str(topic)
 
 
 def __timedelta_to_seconds(timedelta):
-    ms   = 10 ** 6          # microseconds/second
+    ms = 10 ** 6          # microseconds/second
     days = 24 * 60 * 60     # seconds/day
-    
-    ms_as_seconds   = float(timedelta.microseconds) / ms
-    seconds         = float(timedelta.seconds)
+
+    ms_as_seconds = float(timedelta.microseconds) / ms
+    seconds = float(timedelta.seconds)
     days_as_seconds = float(timedelta.days) * days
-    total_seconds   = sum( (ms_as_seconds, 
-                            seconds, 
-                            days_as_seconds) )
+    total_seconds = sum((ms_as_seconds,
+                         seconds,
+                         days_as_seconds))
     return abs(total_seconds)  # abs() comes last
 
 
@@ -191,22 +180,21 @@ def _match_lists(expected, topic):
 def to_be_like(topic, expected):
     '''Asserts that `topic` is like (similar to) `expected`. Allows some leeway.'''
     result = _match_alike(expected, topic)
-
+    is_str = lambda x: isinstance(x, string_types + (binary_type,))
     if not result:
-        if isinstance(topic, string_types + (binary_type, )) and isinstance(expected, string_types + (binary_type, )):
+        if is_str(topic) and is_str(expected):
             matcher, first, second = compare(_strip_string(topic), _strip_string(expected))
             print()
-            print("Expected strings to be equal, but they were different:")
+            print('Expected strings to be equal, but they were different:')
             print(first)
             print(second)
             print()
-        raise AssertionError("Expected '%s' to be like '%s'." % (topic, expected))
+        raise AssertionError("Expected topic('{topic}') to be like '{expected}'".format(topic=topic, expected=expected))
 
 
 @assertion
 def not_to_be_like(topic, expected):
     '''Asserts that `topic` is like (similar to) `expected`. Allows some leeway.'''
     result = _match_alike(expected, topic)
-
     if result:
-        raise AssertionError("Expected '%s' not to be like '%s'." % (topic, expected))
+        raise AssertionError("Expected topic('{topic}') not to be like '{expected}'".format(topic=topic, expected=expected))
\ No newline at end of file
